@@ -6,6 +6,7 @@ contains accessors for pandas
 """
 
 from .dataframe import DataFrameAccessor
+from .index import IndexAccessor
 from .series import SeriesAccessor
 
-__all__ = ["DataFrameAccessor", "SeriesAccessor"]
+__all__ = ["DataFrameAccessor", "SeriesAccessor", "IndexAccessor"]
